罗生门 (豆瓣)
Description: 罗生门电影简介和剧情介绍,罗生门影评、图片、预告片、影讯、论坛、在线购票
Keywords: 罗生门,羅生門,罗生门影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.214豆瓣电影Top250

# 罗生门 羅生門 (1950)

导演: 黑泽明
编剧: 黑泽明 / 桥本忍 / 芥川龙之介
主演: 三船敏郎 / 京町子 / 森雅之 / 志村乔 / 千秋实 / 上田吉二郎 / 本间文子 / 加东大介
类型: 剧情 / 悬疑 / 犯罪
制片国家/地区: 日本
语言: 日语
上映日期: 1950-08-26(日本)
片长: 88分钟
又名: Rashomon
IMDb: tt0042876
豆瓣评分
引用
8.8
297513人评价
5星
51.9%
4星
38.2%
3星
8.9%
2星
0.7%
1星
0.3%
好于 97% 剧情片
好于 98% 悬疑片
想看 看过
评价:
推荐

## 罗生门的剧情简介 · · · · · ·

罗生门，日本京都的正南门。云游和尚、砍柴人和乞丐在城门底下避雨，三人闲聊，话题开始，故事的序幕拉开：一个武士和他妻子路过荒山，遭遇了不测。妻子被侮辱，而武士惨遭杀害。惨案如何酿成？凶手、妻子、借武士亡魂来做证的女巫，都各有说法。
真相只得一个，但是各人提供证词的目的却各有不同。为了美化自己的道德，减轻自己的罪恶，掩饰自己的过失，人人都开始叙述一个美化自己的故事版本。荒山上的惨案，成了一团拨不开看不清的迷雾。
谈论完毕，雨过天晴。砍柴人在罗生门旁发现一个哭泣的弃婴。他决定收养下来，抱着婴孩往夕阳深处走去。 ©豆瓣

## 罗生门的演职员 · · · · · · ( 全部 15 )

- 黑泽明 导演
- 三船敏郎 演员
- 京町子 演员
- 森雅之 演员
- 志村乔 演员
- 千秋实 演员

## 罗生门的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片671 · 添加 )

## 罗生门的获奖情况 · · · · · · ( 全部 )

- 第25届奥斯卡金像奖
- 黑白片最佳艺术指导和布景(提名)
- 松山崇 / 松本春造

- 第12届威尼斯电影节
- 主竞赛单元 金狮奖
- 黑泽明

## 喜欢这部电影的人也喜欢 · · · · · ·

  控方证人

  记忆碎片

  后窗

  穆赫兰道

  惊魂记

  追随

  禁闭岛

  西北偏北

  十二怒汉

  杀人回忆

我要写短评

## 罗生门的短评 · · · · · · ( 全部 69053 条 )

热门 / 最新 / 好友

### 854 有用 400blows 看过 2005-07-07 20:31:13

看不下去啊看不下去啊女主角太丑...

### 2182 有用 自在渍 看过 2010-06-13 10:45:58

如果不是那一阵风

### 197 有用 大头绿豆 看过 2013-07-04 20:19:40

在那个时代它肯定是一部开创性的好电影，但显然无法取悦现在的观众。所有关于人性的讨论都是以对白给出，并且竟然出自乞丐和樵夫。以三船敏郎为首的几个演员，演技跟《七武士》时期几乎一样表面、浮夸，以及慢半拍。人性部分，相信芥川龙之介的原著剖析得会更深刻。

### 902 有用 握不住的灵魂 看过 2012-08-02 20:02:59

「人对于自己的事不会实话实说，谈他自己的事的时候，不可能不加虚饰。这个剧本描写的就是不加虚饰就活不下去的人的本性。甚至可以这样说：人就算死了也不会放弃虚饰，可见人的罪孽如何之深。这是一幅描绘人与生俱来的罪孽和人难以更改的本性、展示人的利己心的奇妙画卷。诸位说仍然不懂这个剧本，因为

### 5749 有用 瞳 看过 2010-11-10 23:09:35

想起史铁生的一句话：“历史在发生时未被发现，在发现时已被重组”，没有绝对的真实能在叙述中被还原。很赞同看过的一个说法“谎言的对立面是宽容”，听者的理解力与接受度影响着叙述者对真相还原的保留度，你若能对他的懦弱退让和罪恶表示宽容，兴许由着这份信任就能更贴近真相了。

> 更多短评 69053条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 罗生门的影评 · · · · · · ( 全部 1536 条 )

热门 / 最新 / 好友
ViViAN LiAnG 2005-12-11 14:06:31

## 罗生门。

这篇影评可能有剧透

黑泽明的《罗生门》，人性中赤裸裸的软弱和谎言。1950年的片子。黑白，粗糙，淳朴。直入人心。 已经是第三次看。依然震撼，毫无厌倦。同时，看到更多的一些东西。 一间破殿，陈旧的牌匾，一场大雨，一个故事。人性就如此丑陋地被呈现出来。 黑泽明的手法独特有力。借着樵夫... (展开)
8046 255 487回应 收起
林愈静 2010-03-30 11:46:15

## 虚荣，我最爱的原罪

基本上，我是个很不错的人。真诚，但不幼稚；清高，而不迂腐；正直严肃，不过幽默感一流。自信满满，却又低调、谦逊。嫉恶如仇，但一直保持热情向上之心。我乐于助人，从不放弃任何一个让座或者扶老太太过马路的机会。我人格健全独立，具有良好的公民意识，是党和国家不可多得... (展开)
995 93 146回应 收起
宇宙大帝 2009-03-11 13:22:26

## 认为影片讲的是虚伪自私和撒谎?哈,那你就是没看懂~~

几乎所有的评论都在讲自私自利,人性的阴暗,然后进行深沉的批判和反思,表达对善良美好的追求. 错啦错啦!! 无论是浪人,武士,女人;还是僧人,樵夫和乞丐,他们都是好样的!他们就应该自私,就应该这么做,这么说!我为他们的表现鼓掌叫好！ 为什么? 你是应该怪罪于某个人的自私,还是应... (展开)
469 110 72回应 收起
潮打空城 2005-11-04 15:10:40

## 人生真相

在我所看过的电影中，《罗生门》无疑是一部杰作。它揭示出人生的真相，象锋利的刀刃划过皮肤一样，既痛且快。真相是，在这个世界上只有事实，没有真实。叙述者越多，我们离真实越远。每个人都是从自己的角度去看世界的，都遵从经济学中的理性人假设，追求自己的利益最大化。武... (展开)
315 48 29回应 收起
三木 2006-12-15 11:47:18

## 从拍摄手法评电影《罗生门》

这篇影评可能有剧透

说到《罗生门》这部影片,其实在这之前我就听说过,但一直没有看,直到前段时间才完整的欣赏完了这部轰动影坛的电影。 影片《罗生门》是由著名剧作家桥本忍根据名作家芥川龙之介创作于１９２１年的短篇小说《筱竹丛中》改编的，是大导演黑泽明的惊世之作，被誉为“有史以来最有价... (展开)
283 22 17回应 收起
冰冽 2005-09-24 21:32:56

## 私欲的软弱

也许选择一个凉爽的秋夜来看这部电影，不是一个好的选择。这不是一部娱乐的电影，通过故事的叙述，更多的恐怕是导演对人性提出的探讨。强盗、武士、女人、樵夫因为各自出发点的不同，将本来简单的一个事件解释的十分复杂。强盗在一阵清风吹来，看到了女人的脚以及娇人的面容，... (展开)
174 64 39回应 收起
Screamy赵爷 2008-08-18 01:57:09

## 别说黑暗，只说脆弱

这篇影评可能有剧透

虽然我无条件反日，虽然黑泽明已经属于名气大到滥俗的导演，不符合我反主流的心理，虽然在看这部电影之前已经知道了大概情节，还是要击节称赏。确确实实是伟大的电影。“人啊！”看完以后心里百味杂陈。看到满世界的影评和介绍抬头便如教科书般总结说道：罗生门揭示了人性的黑... (展开)
114 10 13回应 收起
李露白 2016-11-20 21:24:07 #在黑泽明的作品中，《罗生门》的剧作表现处于什么水平？

## 真相只有一个？

这篇影评可能有剧透

前些日子，香港的大街小巷都在播放歌曲《罗生门》。黄伟文、麦浚龙用十了年讲一个故事。十年前《耿耿于怀》，十年后《念念不忘》，谁知男女对峙，才知是《罗生门》。念念不忘，必有回响，响的是一巴掌！“罗生门”现在指事件当事人各执一词，分别按照对自己有利的方式进行表述... (展开)
92 1 17回应 收起
茶豆豆 2015-09-28 20:57:52

## 犀利镜头语言 人性晦暗一面——简评黑泽明《罗生门》

黑泽明的《罗生门》，1950年上映，是日本影坛的神作。1951年威尼斯电影节上，《罗生门》意外获得当年的威尼斯金狮奖，及第二十四届奥斯卡最佳外语片奖。 对这部片子是先闻其名，后观其影。影片犀利地揭露了人性的丑陋阴暗——剧中每个人物为了个人的利益、自己的私... (展开)
71 25 3回应 收起
费费 2019-05-17 20:35:49

## 印象派、印象主义与西方哲学

出于一个展现人性复杂度的动机，黑泽明在构思影片构图与影像和音乐之间的乘法时，摒弃了当时日本电影盛行的注重形与神的古典主义风格，而考虑了注重光与影的印象派，作为影片形式风格的主力，印象派因为在影片中表现形式上的深入，而表现出了印象主义。与作为表现形式风格的印... (展开)
43 1 0回应 收起

> 更多影评 1536篇

添加新讨论

## 讨论区 · · · · · ·

这部电影竟然进不了top100 | 来自随遇而安 |  | 2022-11-22 15:45:11
江歌案件4方证词与罗生门 | 来自劝百讽一 | 1 回应 | 2022-11-16 10:59:49
罗生门里的真相到底是什么？ | 来自豆友216328927 | 21 回应 | 2022-11-13 07:16:39
别争女人了，我看这几个男的全都是真的丑 | 来自个人账号 | 7 回应 | 2022-11-13 06:37:42
这种剧情逻辑很熟悉，有别的电影也借用了吗 | 来自Grandpa | 6 回应 | 2022-11-10 19:48:49

> 去这部影片的讨论区（全部202条）

## 关于《罗生门》的问题 · · · · · · ( 全部17个 )

- 跳轴了，什么情况？ 8人回答
- 武士真的是强盗杀的么？也可能是樵夫杀的啊？ 7人回答

> 全部17个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 哔哩哔哩 免费观看
- 1905电影网 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 今敏《造梦机器》剧组100部电影推荐 (恶魔的步调)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 【电影旬报】20世纪最佳100部日本片 (桃桃林林)
- 有生之年非看不可的1001部电影 (Viking)

## 谁在看这部电影 · · · · · ·

- 柠萌茶
  8分钟前 看过
- # 北平遗址
  10分钟前 看过
- momo
  15分钟前 想看

451632人看过 / 266724人想看

订阅罗生门的评论:
feed: rss 2.0